.. _how_to:

How to ...
==========

| These documents should serve as recipes to solve specific issues, they should answer "How to ..." questions.
| They are meant to be used by user who already have some knowledge of icclim and want recipes to solve specific problems.

To grasp the basic usage of icclim, you may consider following :ref:`tutorials` first.
To find more in depth technical knowledge see :ref:`references`.

.. toctree::
    :maxdepth: 2
    :caption: Contents:

    Chunk data and parallelize computation <dask>
    Jupyter notebooks <notebooks>
    Compute ECA&D indices <recipes_ecad>
    Customize indices <recipes_custom>
    Use icclim through OCGIS <ocgis>
